@@ -1,4 +1,4 @@
-# Copyright (c) 2020, Riverbank Computing Limited
+# Copyright (c) 2022, Riverbank Computing Limited
 # All rights reserved.
 #
 # This copy of PyQt-builder is licensed for use under the terms of the SIP
@@ -24,11 +24,13 @@
 
 import os
 import sys
+import sysconfig
 
 from sipbuild import (Buildable, BuildableModule, Builder, Option, Project,
         PyProjectOptionException, UserException)
 
 from .installable import QmakeTargetInstallable
+from .version import PYQTBUILD_VERSION_STR
 
 
 class QmakeBuilder(Builder):
@@ -54,9 +56,10 @@ class QmakeBuilder(Builder):
             # it.  However for our own frontends we want to use the version
             # corresponding to the frontend (and, anyway, the frontend may not
             # be on PATH).
-            if tool != 'pep517':
-                self._sip_distinfo = os.path.join(
-                        os.path.abspath(os.path.dirname(sys.argv[0])),
+            exe_dir, exe_name = os.path.split(sys.argv[0])
+
+            if exe_name.startswith('sip-'):
+                self._sip_distinfo = os.path.join(os.path.abspath(exe_dir),
                         self._sip_distinfo)
 
             # Check we have a qmake.
@@ -79,8 +82,8 @@ class QmakeBuilder(Builder):
             if self.spec is None:
                 self.spec = self.qt_configuration['QMAKE_SPEC']
 
-                # The binary OS/X Qt installer used to default to XCode.  If so
-                # then use macx-clang.
+                # The Qt installer used to default to XCode.  If so then use
+                # macx-clang.
                 if self.spec == 'macx-xcode':
                     # This will exist (and we can't check anyway).
                     self.spec = 'macx-clang'
@@ -103,6 +106,8 @@ class QmakeBuilder(Builder):
                 py_platform = 'wasm'
             elif 'win32' in xspec:
                 py_platform = 'win32'
+            elif 'mingw-w64' in xspec:
+                py_platform = 'win32'
             else:
                 # Treat everything else as Linux.
                 py_platform = 'linux'
@@ -137,18 +142,13 @@ class QmakeBuilder(Builder):
 
             # Set the default ABI version of the sip module.
             if not project.abi_version:
-                # The defaults should really be the .0 versions but we
-                # originally didn't specify a minor version so that SIP
-                # defaulted to the latest version it knew about (which may vary
-                # according to the SIP version).  We therefore specify the
-                # minimum version needed by the current versions of PyQt at the
-                # time of writing.  If later versions of PyQt have different
-                # requirements then they will explicitly specify the required
-                # version.
+                # These are the minimum recommended versions.  They usually
+                # correspond to specific functionality that users would expect
+                # to be enabled.
                 if project.sip_module == 'PyQt5.sip':
-                    project.abi_version = '12.8'
+                    project.abi_version = '12.11'
                 elif project.sip_module == 'PyQt6.sip':
-                    project.abi_version = '13.1'
+                    project.abi_version = '13.4'
 
         super().apply_user_defaults(tool)
 
@@ -230,7 +230,8 @@ class QmakeBuilder(Builder):
             inventory.close()
 
             args = project.get_sip_distinfo_command_line(self._sip_distinfo,
-                    inventory_fn, generator=os.path.basename(sys.argv[0]),
+                    inventory_fn, generator='pyqtbuild',
+                    generator_version=PYQTBUILD_VERSION_STR,
                     wheel_tag=wheel_tag)
             args.append(self.qmake_quote(project.get_distinfo_dir(target_dir)))
 
@@ -336,8 +337,8 @@ class QmakeBuilder(Builder):
         """ Return the name of a valid make program. """
 
         if self.project.py_platform == 'win32':
-            if self.spec == 'win32-g++':
-                make = 'mingw32-make'
+            if 'g++' in self.spec:
+                make = 'make'
             else:
                 make = 'nmake'
         else:
@@ -677,6 +678,13 @@ macx {
 
         buildable.make_names_relative()
 
+        # Handle the target architecture(s).  The way that Python handles
+        # 'universal2' seems broken as it is determined by what versions of
+        # macOS and the SDK the interpreter was built against rather than the
+        # versions that are being used now.
+        if self.project.get_platform_tag().endswith('_universal2'):
+            pro_lines.append('QMAKE_APPLE_DEVICE_ARCHS = x86_64 arm64')
+
         # Handle debugging.
         pro_lines.append(
                 'CONFIG += {}'.format(
