@@ -1,4 +1,4 @@
-# Copyright (c) 2021, Riverbank Computing Limited
+# Copyright (c) 2022, Riverbank Computing Limited
 # All rights reserved.
 #
 # This copy of PyQt-builder is licensed for use under the terms of the SIP
@@ -60,7 +60,10 @@ _QT_METADATA = {
 
     'QtGui': (
         VersionedMetadata(version=(6, 2, 0),
-                lib_deps={'linux': ('QtWaylandClient', 'QtXcbQpa')},
+                lib_deps={
+                        'linux': ('QtWaylandClient',
+                                'QtWaylandEglClientHwIntegration',
+                                'QtWlShellIntegration', 'QtXcbQpa')},
                 other_lib_deps={
                         'win': ('d3dcompiler_47.dll', 'opengl32sw.dll')}),
         VersionedMetadata(lib_deps={'linux': ('QtWaylandClient', 'QtXcbQpa')},
@@ -93,6 +96,13 @@ _QT_METADATA = {
     'QtOpenGLWidgets':
         VersionedMetadata(),
 
+    'QtPdf':
+        VersionedMetadata(version=(6, 4, 0),
+                lib_deps={'': ('QtPdfQuick', )}),
+
+    'QtPdfWidgets':
+        VersionedMetadata(version=(6, 4, 0)),
+
     'QtPositioning':
         VersionedMetadata(version=(6, 2, 0),
                 lib_deps={'': ('QtPositioningQuick', )},
@@ -122,6 +132,14 @@ _QT_METADATA = {
                 qml=True)),
 
     'QtQuick3D': (
+        VersionedMetadata(version=(6, 4, 0),
+                lib_deps={
+                        '': ('QtConcurrent', 'QtQuick3DAssetImport',
+                        'QtQuick3DAssetUtils', 'QtQuick3DEffects',
+                        'QtQuick3DHelpers', 'QtQuick3DIblBaker',
+                        'QtQuick3DParticles', 'QtQuick3DRuntimeRender',
+                        'QtQuick3DUtils', 'QtShaderTools')},
+                qml=True),
         VersionedMetadata(version=(6, 1, 0),
                 lib_deps={
                         '': ('QtQuick3DAssetImport', 'QtQuick3DAssetUtils',
@@ -164,8 +182,8 @@ _QT_METADATA = {
     'QtTest':
         VersionedMetadata(qml=True),
 
-    #'QtTextToSpeech':
-    #    VersionedMetadata(),
+    'QtTextToSpeech':
+        VersionedMetadata(version=(6, 4, 0), qml=True),
 
     'QtWebChannel':
         VersionedMetadata(version=(6, 2, 0), qml=True),
